@@ -5,7 +5,7 @@ docs.  In setup.py in particular, we exec this file, so it cannot import nipy
 
 # nipype version information
 # Remove -dev for release
-__version__ = "1.7.1"
+__version__ = "1.8.1"
 
 
 def get_nipype_gitversion():
@@ -54,14 +54,13 @@ CLASSIFIERS = [
     "License :: OSI Approved :: Apache Software License",
     "Operating System :: MacOS :: MacOS X",
     "Operating System :: POSIX :: Linux",
-    "Programming Language :: Python :: 3.6",
     "Programming Language :: Python :: 3.7",
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
     "Programming Language :: Python :: 3.10",
     "Topic :: Scientific/Engineering",
 ]
-PYTHON_REQUIRES = ">= 3.6"
+PYTHON_REQUIRES = ">= 3.7"
 
 description = "Neuroimaging in Python: Pipelines and Interfaces"
 
@@ -102,15 +101,12 @@ existing pipeline systems.
 # versions
 NIBABEL_MIN_VERSION = "2.1.0"
 NETWORKX_MIN_VERSION = "2.0"
-# Numpy bug in python 3.7:
-# https://www.opensourceanswers.com/blog/you-shouldnt-use-python-37-for-data-science-right-now.html
-NUMPY_MIN_VERSION = "1.15.3"
+NUMPY_MIN_VERSION = "1.17"
 SCIPY_MIN_VERSION = "0.14"
 TRAITS_MIN_VERSION = "4.6"
 DATEUTIL_MIN_VERSION = "2.2"
-FUTURE_MIN_VERSION = "0.16.0"
 SIMPLEJSON_MIN_VERSION = "3.8.0"
-PROV_VERSION = "1.5.2"
+PROV_MIN_VERSION = "1.5.2"
 RDFLIB_MIN_VERSION = "5.0.0"
 CLICK_MIN_VERSION = "6.6.0"
 PYDOT_MIN_VERSION = "1.2.3"
@@ -141,7 +137,7 @@ REQUIRES = [
     "nibabel>=%s" % NIBABEL_MIN_VERSION,
     "numpy>=%s" % NUMPY_MIN_VERSION,
     "packaging",
-    "prov>=%s" % PROV_VERSION,
+    "prov>=%s" % PROV_MIN_VERSION,
     "pydot>=%s" % PYDOT_MIN_VERSION,
     "python-dateutil>=%s" % DATEUTIL_MIN_VERSION,
     "rdflib>=%s" % RDFLIB_MIN_VERSION,
@@ -150,6 +146,7 @@ REQUIRES = [
     "traits>=%s,!=5.0" % TRAITS_MIN_VERSION,
     "filelock>=3.0.0",
     "etelemetry>=0.2.0",
+    "looseversion",
 ]
 
 TESTS_REQUIRES = [
